package com.muyu.product.domain;

import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

/**
 * 品类属性组中间对象 category_attribute_group
 *
 * @author saisai
 * @date 2024-02-29
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = true)
public class CategoryAttributeGroup extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 属性组编号
     */
    @Excel(name = "属性组编号")
    private Long attributeGroupId;

    /**
     * 品类编号
     */
    @Excel(name = "品类编号")
    private Long categoryId;

    /**
     * 品类属性组中间表构建体
     * 作用：提供数组对象
     *
     * @param id
     * @param groupId
     * @return
     */
    public static CategoryAttributeGroup saveBuilder(Long id, Long groupId, Supplier<String> username) {
        return CategoryAttributeGroup.builder()
                .attributeGroupId(groupId)
                .categoryId(id)
                .createBy(username.get())
                .createTime(new Date())
                .build();
    }

    public static List<CategoryAttributeGroup> saveBuilderList(CategoryInfoSaveModel categoryReq, Supplier<String> username) {
        return categoryReq.getCheckedAttributeGroupIds().stream().map(
                groupId -> saveBuilder(categoryReq.getId(), groupId, username)
        ).toList();
    }
}
