package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.muyu.product.domain.AttributeGroup;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.AsAttributeGroup;
import com.muyu.product.service.IAsAttributeGroupService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 属性组中间Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/as_attribute_group")
public class AsAttributeGroupController extends BaseController
{
    @Autowired
    private IAsAttributeGroupService asAttributeGroupService;

    /**
     * 查询属性组中间列表
     */
    @RequiresPermissions("product:as_attribute_group:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AsAttributeGroup>> list(AsAttributeGroup asAttributeGroup)
    {
        startPage();
        List<AsAttributeGroup> list = asAttributeGroupService.selectAsAttributeGroupList(asAttributeGroup);
        return getDataTable(list);
    }

    /**
     * 导出属性组中间列表
     */
    @RequiresPermissions("product:as_attribute_group:export")
    @Log(title = "属性组中间", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AsAttributeGroup asAttributeGroup)
    {
        List<AsAttributeGroup> list = asAttributeGroupService.selectAsAttributeGroupList(asAttributeGroup);
        ExcelUtil<AsAttributeGroup> util = new ExcelUtil<AsAttributeGroup>(AsAttributeGroup.class);
        util.exportExcel(response, list, "属性组中间数据");
    }

    /**
     * 获取属性组中间详细信息
     */
    @RequiresPermissions("product:as_attribute_group:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(asAttributeGroupService.selectAsAttributeGroupById(id));
    }

    /**
     * 新增属性组中间
     */
    @RequiresPermissions("product:as_attribute_group:add")
    @Log(title = "属性组中间", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody AsAttributeGroup asAttributeGroup)
    {
        return toAjax(asAttributeGroupService.insertAsAttributeGroup(asAttributeGroup));
    }

    /**
     * 修改属性组中间
     */
    @RequiresPermissions("product:as_attribute_group:edit")
    @Log(title = "属性组中间", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody AsAttributeGroup asAttributeGroup)
    {
        return toAjax(asAttributeGroupService.updateAsAttributeGroup(asAttributeGroup));
    }

    /**
     * 删除属性组中间
     */
    @RequiresPermissions("product:as_attribute_group:remove")
    @Log(title = "属性组中间", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(asAttributeGroupService.deleteAsAttributeGroupByIds(ids));
    }
}
