package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.Attribute;
import com.muyu.product.service.IAttributeService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 属性Controller
 *
 * @author saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/attribute")
public class AttributeController extends BaseController
{
    @Autowired
    private IAttributeService attributeService;

    /**
     * 查询属性列表
     */
    @RequiresPermissions("product:attribute:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Attribute>> list(Attribute attribute)
    {
        startPage();
        List<Attribute> list = attributeService.selectAttributeList(attribute);
        return getDataTable(list);
    }

    /**
     * 导出属性列表
     */
    @RequiresPermissions("product:attribute:export")
    @Log(title = "属性", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Attribute attribute)
    {
        List<Attribute> list = attributeService.selectAttributeList(attribute);
        ExcelUtil<Attribute> util = new ExcelUtil<Attribute>(Attribute.class);
        util.exportExcel(response, list, "属性数据");
    }

    /**
     * 获取属性详细信息
     */
    @RequiresPermissions("product:attribute:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(attributeService.selectAttributeById(id));
    }

    /**
     * 新增属性
     */
    @RequiresPermissions("product:attribute:add")
    @Log(title = "属性", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Attribute attribute)
    {
        return toAjax(attributeService.insertAttribute(attribute));
    }

    /**
     * 修改属性
     */
    @RequiresPermissions("product:attribute:edit")
    @Log(title = "属性", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Attribute attribute)
    {
        return toAjax(attributeService.updateAttribute(attribute));
    }

    /**
     * 删除属性
     */
    @RequiresPermissions("product:attribute:remove")
    @Log(title = "属性", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(attributeService.deleteAttributeByIds(ids));
    }
}
