package com.muyu.product.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.AttributeProduct;
import com.muyu.product.service.IAttributeProductService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 商品属性中间表Controller
 *
 * @author Saisai
 * @date 2024-02-29
 */
@RestController
@RequestMapping("/product")
public class AttributeProductController extends BaseController
{
    @Autowired
    private IAttributeProductService attributeProductService;

    /**
     * 查询商品属性中间表列表
     */
    @RequiresPermissions("product:product:list")
    @GetMapping("/list")
    public Result<TableDataInfo<AttributeProduct>> list(AttributeProduct attributeProduct)
    {
        startPage();
        List<AttributeProduct> list = attributeProductService.selectAttributeProductList(attributeProduct);
        return getDataTable(list);
    }

    /**
     * 导出商品属性中间表列表
     */
    @RequiresPermissions("product:product:export")
    @Log(title = "商品属性中间表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AttributeProduct attributeProduct)
    {
        List<AttributeProduct> list = attributeProductService.selectAttributeProductList(attributeProduct);
        ExcelUtil<AttributeProduct> util = new ExcelUtil<AttributeProduct>(AttributeProduct.class);
        util.exportExcel(response, list, "商品属性中间表数据");
    }

    /**
     * 获取商品属性中间表详细信息
     */
    @RequiresPermissions("product:product:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(attributeProductService.selectAttributeProductById(id));
    }

    /**
     * 新增商品属性中间表
     */
    @RequiresPermissions("product:product:add")
    @Log(title = "商品属性中间表", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody AttributeProduct attributeProduct)
    {
        return toAjax(attributeProductService.insertAttributeProduct(attributeProduct));
    }

    /**
     * 修改商品属性中间表
     */
    @RequiresPermissions("product:product:edit")
    @Log(title = "商品属性中间表", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody AttributeProduct attributeProduct)
    {
        return toAjax(attributeProductService.updateAttributeProduct(attributeProduct));
    }

    /**
     * 删除商品属性中间表
     */
    @RequiresPermissions("product:product:remove")
    @Log(title = "商品属性中间表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(attributeProductService.deleteAttributeProductByIds(ids));
    }
}
