package com.muyu.product.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.product.domain.RuleAttr;
import com.muyu.product.domain.req.RuleAttrReq;
import com.muyu.product.service.RuleAttrService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * Controller
 *
 * @author muyu
 * @date 2024-03-07
 */
@RestController
@RequestMapping("/attr")
public class RuleAttrController extends BaseController {
    @Autowired
    private RuleAttrService ruleAttrService;

    /**
     * 查询列表
     */
    @RequiresPermissions("system:attr:list")
    @GetMapping("/list")
    public Result<TableDataInfo<RuleAttr>> list(RuleAttr ruleAttr) {
        startPage();
        List<RuleAttr> list = ruleAttrService.selectRuleAttrList(ruleAttr);
        return getDataTable(list);
    }

    /**
     * 导出列表
     */
    @RequiresPermissions("system:attr:export")
    @Log(title = "", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RuleAttr ruleAttr) {
        List<RuleAttr> list = ruleAttrService.selectRuleAttrList(ruleAttr);
        ExcelUtil<RuleAttr> util = new ExcelUtil<RuleAttr>(RuleAttr.class);
        util.exportExcel(response, list, "数据");
    }

    /**
     * 获取详细信息
     */
    @RequiresPermissions("system:attr:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id) {
        return success(ruleAttrService.selectRuleAttrById(id));
    }

    /**
     * 新增
     */
//    @RequiresPermissions("system:attr:add")
//    @Log(title = "", businessType = BusinessType.INSERT)
//    @PostMapping
//    public Result add(@RequestBody RuleAttr ruleAttr) {
//        return toAjax(ruleAttrService.insertRuleAttr(ruleAttr));
//    }

    /**
     * 新增
     */
    @RequiresPermissions("system:attr:add")
    @Log(title = "", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody RuleAttrReq ruleAttrReq) {
        return ruleAttrService.saveBatch(RuleAttr.saveBuilder(ruleAttrReq,SecurityUtils::getUsername))
                ? Result.success("","批量添加成功") : Result.error("添加失败") ;
    }



    /**
     * 修改
     */
    @RequiresPermissions("system:attr:edit")
    @Log(title = "", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody RuleAttr ruleAttr) {
        return toAjax(ruleAttrService.updateRuleAttr(ruleAttr));
    }

    /**
     * 删除
     */
    @RequiresPermissions("system:attr:remove")
    @Log(title = "", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids) {
        return toAjax(ruleAttrService.deleteRuleAttrByIds(ids));
    }
}
