package com.muyu.product.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.product.domain.Address;
import com.muyu.product.domain.CategoryInfo;
import com.muyu.product.domain.model.CategoryInfoSaveModel;
import com.muyu.product.domain.req.CategoryReq;
import com.muyu.product.domain.resp.CategoryResp;

/**
 * 品类信息Service接口
 *
 * @author Saisai
 * @date 2024-02-29
 */
public interface ICategoryInfoService extends IService<CategoryInfo>
{
    /**
     * 查询品类信息
     *
     * @param id 品类信息主键
     * @return 品类信息
     */
    CategoryInfo selectCategoryInfoById(Long id);

    /**
     * 查询品类信息列表
     *
     * @param  categoryInfoSaveModel 品类信息
     * @return 品类信息集合
     */
    List<CategoryResp> selectCategoryInfoList(CategoryInfoSaveModel categoryInfoSaveModel);

    /**
     * 新增品类信息
     *
     * @param categoryInfoSaveModel 品类信息
     * @return 结果
     */
    int insertCategoryInfo(CategoryInfoSaveModel categoryInfoSaveModel);

    /**
     * 修改品类信息
     *
     * @param categoryInfoSaveModel 品类信息
     * @return 结果
     */
    boolean updateCategoryInfo(CategoryInfoSaveModel categoryInfoSaveModel);

    /**
     * 批量删除品类信息
     *
     * @param ids 需要删除的品类信息主键集合
     * @return 结果
     */
    int deleteCategoryInfoByIds(Long[] ids);

    /**
     * 删除品类信息信息
     *
     * @param id 品类信息主键
     * @return 结果
     */
    int deleteCategoryInfoById(Long id);

    boolean save(CategoryInfoSaveModel categoryInfoSaveModel);
}
