package com.muyu.product.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.product.mapper.ProductInfoMapper;
import com.muyu.product.domain.ProductInfo;
import com.muyu.product.service.IProductInfoService;

/**
 * 商品;Service业务层处理
 *
 * @author Saisai
 * @date 2024-02-29
 */
@Service
public class ProductInfoServiceImpl extends ServiceImpl<ProductInfoMapper,ProductInfo> implements IProductInfoService
{
    @Autowired
    private ProductInfoMapper productInfoMapper;

    /**
     * 查询商品;
     *
     * @param id 商品;主键
     * @return 商品;
     */
    @Override
    public ProductInfo selectProductInfoById(Long id)
    {
        return productInfoMapper.selectProductInfoById(id);
    }

    /**
     * 查询商品;列表
     *
     * @param productInfo 商品;
     * @return 商品;
     */
    @Override
    public List<ProductInfo> selectProductInfoList(ProductInfo productInfo)
    {
        return productInfoMapper.selectProductInfoList(productInfo);
    }

    /**
     * 新增商品;
     *
     * @param productInfo 商品;
     * @return 结果
     */
    @Override
    public int insertProductInfo(ProductInfo productInfo)
    {
        return productInfoMapper.insertProductInfo(productInfo);
    }

    /**
     * 修改商品;
     *
     * @param productInfo 商品;
     * @return 结果
     */
    @Override
    public int updateProductInfo(ProductInfo productInfo)
    {
        productInfo.setUpdateTime(DateUtils.getNowDate());
        return productInfoMapper.updateProductInfo(productInfo);
    }

    /**
     * 批量删除商品;
     *
     * @param ids 需要删除的商品;主键
     * @return 结果
     */
    @Override
    public int deleteProductInfoByIds(Long[] ids)
    {
        return productInfoMapper.deleteProductInfoByIds(ids);
    }

    /**
     * 删除商品;信息
     *
     * @param id 商品;主键
     * @return 结果
     */
    @Override
    public int deleteProductInfoById(Long id)
    {
        return productInfoMapper.deleteProductInfoById(id);
    }
}
